summaryrefslogtreecommitdiffstats
path: root/konsolekalendar/konsolekalendar.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'konsolekalendar/konsolekalendar.cpp')
-rw-r--r--konsolekalendar/konsolekalendar.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/konsolekalendar/konsolekalendar.cpp b/konsolekalendar/konsolekalendar.cpp
index 564adf53..f8c5fa99 100644
--- a/konsolekalendar/konsolekalendar.cpp
+++ b/konsolekalendar/konsolekalendar.cpp
@@ -20,8 +20,8 @@
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
* *
* As a special exception, permission is given to link this program *
* with any edition of Qt, and distribute the resulting executable, *
* without including the source code for Qt in the source distribution. *
* *
******************************************************************************/
/**
@@ -271,20 +271,20 @@ bool KonsoleKalendar::showInstance()
} else {
if ( firstdate == lastdate ) {
title = i18n( "Events: %1" )
- .arg( firstdate.toString( Qt::TextDate ) );
+ .arg( firstdate.toString( TQt::TextDate ) );
} else {
title = i18n( "Events: %1 - %2" )
- .arg( firstdate.toString( Qt::TextDate ) )
- .arg( lastdate.toString( Qt::TextDate ) );
+ .arg( firstdate.toString( TQt::TextDate ) )
+ .arg( lastdate.toString( TQt::TextDate ) );
}
htmlSettings.setEventView( true );
}
htmlSettings.setEventTitle( title );
htmlSettings.setEventAttendees( true );
// Not supporting Todos yet
-// title = "To-Do List for " + firstdate.toString(Qt::TextDate);
+// title = "To-Do List for " + firstdate.toString(TQt::TextDate);
// if ( firstdate != lastdate ) {
-// title += " - " + lastdate.toString(Qt::TextDate);
+// title += " - " + lastdate.toString(TQt::TextDate);
// }
htmlSettings.setTodoListTitle( title );
htmlSettings.setTodoView( false );
@@ -438,11 +438,11 @@ void KonsoleKalendar::printSpecs()
<< endl;
cout << i18n( " Begin: %1" ).
- arg( m_variables->getStartDateTime().toString( Qt::TextDate ) ).local8Bit()
+ arg( m_variables->getStartDateTime().toString( TQt::TextDate ) ).local8Bit()
<< endl;
cout << i18n( " End: %1" ).
- arg( m_variables->getEndDateTime().toString( Qt::TextDate ) ).local8Bit()
+ arg( m_variables->getEndDateTime().toString( TQt::TextDate ) ).local8Bit()
<< endl;
if ( m_variables->getFloating() == true ) {
@@ -20,8 +20,8 @@
* *
* As a special exception, permission is given to link this program *
- * with any edition of Qt, and distribute the resulting executable, *
- * without including the source code for Qt in the source distribution. *
+ * with any edition of TQt, and distribute the resulting executable, *
+ * without including the source code for TQt in the source distribution. *
* *
******************************************************************************/